@@ -11,11 +11,11 @@ use crate::parse::{HostLang, TypeDeclarations};
 use crate::SWIFT_BRIDGE_PREFIX;
 
 use self::bridged_option::BridgedOption;
-pub(crate) use self::shared_struct::{
-    NamedStructField, SharedStruct, StructFields, StructSwiftRepr, UnnamedStructField,
-};
+pub(crate) use self::shared_enum::{EnumVariant, SharedEnum};
+pub(crate) use self::shared_struct::{SharedStruct, StructFields, StructSwiftRepr};
 
 mod bridged_option;
+mod shared_enum;
 mod shared_struct;
 
 // FIXME: Rename to BridgedType
@@ -168,6 +168,7 @@ impl BridgedType {
 #[derive(Debug, PartialEq, Clone)]
 pub(crate) enum SharedType {
     Struct(SharedStruct),
+    Enum(SharedEnum),
 }
 
 #[derive(Clone)]
@@ -413,6 +414,10 @@ impl BridgedType {
                     #ty_name
                 }
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                //
+                todo!("Shared enum to Rust type name")
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let ty_name = &opaque.ty.ident;
 
@@ -545,6 +550,12 @@ impl BridgedType {
                     ))) => {
                         todo!("Option<SharedStruct> is not yet supported")
                     }
+                    BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(
+                        shared_enum,
+                    ))) => {
+                        let name = shared_enum.ffi_option_name_tokens();
+                        quote! { #name }
+                    }
                     BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                         let type_name = &opaque.ident;
 
@@ -567,6 +578,11 @@ impl BridgedType {
 
                 prefixed_ty_name
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                let ffi_ty_name = shared_enum.ffi_name_tokens();
+
+                quote! { #ffi_ty_name }
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let ty_name = &opaque.ty.ident;
 
@@ -692,6 +708,19 @@ impl BridgedType {
                     TypePosition::SharedStructField => shared_struct.swift_name_string(),
                 }
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                match type_pos {
+                    TypePosition::FnArg(func_host_lang)
+                    | TypePosition::FnReturn(func_host_lang) => {
+                        if func_host_lang.is_rust() {
+                            shared_enum.swift_name_string()
+                        } else {
+                            shared_enum.ffi_name_string()
+                        }
+                    }
+                    TypePosition::SharedStructField => shared_enum.swift_name_string(),
+                }
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 if opaque.host_lang.is_rust() {
                     match type_pos {
@@ -777,6 +806,9 @@ impl BridgedType {
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(shared_struct))) => {
                 format!("struct {}", shared_struct.ffi_name_string())
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                format!("struct {}", shared_enum.ffi_name_string())
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 if opaque.host_lang.is_rust() {
                     "void*".to_string()
@@ -891,6 +923,11 @@ impl BridgedType {
                     #expression.into_ffi_repr()
                 }
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                quote! {
+                    #expression.into_ffi_repr()
+                }
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let ty_name = &opaque.ty.ident;
 
@@ -972,6 +1009,11 @@ impl BridgedType {
                     #value.into_rust_repr()
                 }
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                quote_spanned! {span=>
+                    #value.into_rust_repr()
+                }
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 if opaque.host_lang.is_rust() {
                     if opaque.reference {
@@ -1073,6 +1115,9 @@ impl BridgedType {
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
                 format!("{}.intoSwiftRepr()", value)
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                format!("{}.intoSwiftRepr()", value)
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let mut ty_name = opaque.ty.ident.to_string();
 
@@ -1175,6 +1220,9 @@ impl BridgedType {
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
                 format!("{}.intoFfiRepr()", value)
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                format!("{}.intoFfiRepr()", value)
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let ty_name = &opaque.ty.ident;
 
@@ -1251,8 +1299,12 @@ impl BridgedType {
                 StdLibType::Vec(_vec) => Some("stdint.h"),
                 _ => None,
             },
-            // TODO: Iterate over the fields and see if any of them need imports..
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
+                // TODO: Iterate over the fields and see if any of them need imports..
+                None
+            }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                // TODO: Iterate over the fields and see if any of them need imports..
                 None
             }
             BridgedType::Foreign(CustomBridgedType::Opaque(_opaque)) => None,
@@ -1327,6 +1379,13 @@ impl BridgedType {
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
                 todo!("Support Option<SharedStruct>")
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                let option_name = shared_enum.ffi_option_name_tokens();
+                UnusedOptionNoneValue {
+                    rust: quote! { #option_name { is_some: false, val: std::mem::MaybeUninit::uninit() } },
+                    swift: "TODO..Support Swift Option<Enum>::None value".into(),
+                }
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let ty_name = &opaque.ty.ident;
 
@@ -1356,6 +1415,10 @@ impl BridgedType {
                 // TODO: Check fields for String
                 false
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                // TODO: Check fields for &str
+                false
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(_)) => false,
         }
     }
@@ -1374,6 +1437,10 @@ impl BridgedType {
                 // TODO: Check fields for &str
                 false
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                // TODO: Check fields for &str
+                false
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(_)) => false,
         }
     }
