@@ -104,8 +104,14 @@ impl BridgedOption {
                     todo!("Support Option<Option<T>>")
                 }
             },
-            BridgedType::Foreign(CustomBridgedType::Shared(_shared_type)) => {
-                todo!("Support Option<SharedType>")
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
+                todo!("Support Option<SharedStruct>")
+            }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                let option_name = shared_enum.ffi_option_name_tokens();
+                quote! {
+                    #option_name::from_rust_repr(#expression)
+                }
             }
             BridgedType::Foreign(CustomBridgedType::Opaque(_opaque_type)) => {
                 quote! {
@@ -167,9 +173,14 @@ impl BridgedOption {
                     todo!("Option<Option<T>> is not yet supported")
                 }
             },
-            BridgedType::Foreign(CustomBridgedType::Shared(_shared_struct)) => {
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
                 todo!("Option<SharedStruct> is not yet supported")
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                quote! {
+                    #value.into_rust_repr()
+                }
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(_opaque)) => {
                 quote! {
                     if #value.is_null() {
@@ -225,8 +236,11 @@ impl BridgedOption {
                     todo!("Support Option<Option<T>>")
                 }
             },
-            BridgedType::Foreign(CustomBridgedType::Shared(_shared)) => {
-                todo!("Support Option<SharedType>")
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
+                todo!("Support Option<SharedStruct>")
+            }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(_shared_enum))) => {
+                format!("{expression}.intoSwiftRepr()", expression = expression)
             }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
                 let type_name = opaque.swift_name();
@@ -304,6 +318,14 @@ impl BridgedOption {
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
                 todo!("Shared structs within options are not yet supported")
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                let ffi_name = shared_enum.ffi_option_name_string();
+                format!(
+                    "{ffi_name}.fromSwiftRepr({expression})",
+                    ffi_name = ffi_name,
+                    expression = expression
+                )
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(_opaque)) => {
                 format!("{{ if let val = {expression} {{ val.isOwned = false; return val.ptr }} else {{ return nil }} }}()", expression = expression,)
             }
@@ -349,6 +371,9 @@ impl BridgedOption {
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
                 todo!("Option<SharedStruct> is not yet supported")
             }
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
+                format!("struct {}", shared_enum.ffi_option_name_string())
+            }
             BridgedType::Foreign(CustomBridgedType::Opaque(_opaque)) => "void*".to_string(),
         }
     }
