@@ -7,7 +7,7 @@ use std::fmt::{Debug, Formatter};
 use syn::spanned::Spanned;
 use syn::{LitStr, Path};
 
-pub(crate) use self::struct_field::{NamedStructField, StructFields, UnnamedStructField};
+pub(crate) use self::struct_field::StructFields;
 
 mod struct_field;
 
