@@ -16,6 +16,7 @@ use crate::{SwiftBridgeModule, SWIFT_BRIDGE_PREFIX};
 
 mod vec;
 
+mod shared_enum;
 mod shared_struct;
 
 impl SwiftBridgeModule {
@@ -89,6 +90,12 @@ impl SwiftBridgeModule {
                         swift += "\n";
                     }
                 }
+                TypeDeclaration::Shared(SharedTypeDeclaration::Enum(shared_enum)) => {
+                    if let Some(swift_enum) = self.generate_shared_enum_string(shared_enum) {
+                        swift += &swift_enum;
+                        swift += "\n";
+                    }
+                }
                 TypeDeclaration::Opaque(ty) => match ty.host_lang {
                     HostLang::Rust => {
                         let class_protocols = class_protocols.get(&ty.ty.ident.to_string());
